#
# spec file for package drbd-formula
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define fname drbd
%define fdir %{_datadir}/salt-formulas
# See also https://en.opensuse.org/openSUSE:Specfile_guidelines
Name:           drbd-formula
Version:        0.4.2+git.1616116365.1e3ab34
Release:        lp152.2.6.1
Summary:        DRBD deployment salt formula
License:        Apache-2.0
URL:            https://github.com/SUSE/%{name}
Source0:        %{name}-%{version}.tar.gz
Requires:       drbd-utils
Requires:       salt-shaptools >= 0.2.9
BuildArch:      noarch
%if 0%{?suse_version} < 1500
Recommends:     salt-formulas-configuration
%else
Requires:       salt-formulas-configuration
%endif

%description
DRBD deployment salt formula
Available on SUSE manager 4.0

In order to use the formula, salt must be available in the system. The package comes automatically
in SLE15. To use it in SLE12, salt (and it sub-components) comes from the Advanced systems management
module, which can be added running the `SUSEConnect -p sle-module-adv-systems-management/12/{{ arch }}`

%prep
%setup -q

%build

%install
mkdir -p %{buildroot}%{fdir}/states/%{fname}
mkdir -p %{buildroot}%{fdir}/metadata/%{fname}
cp -R %{fname} %{buildroot}%{fdir}/states
cp -R templates %{buildroot}%{fdir}/states/%{fname}
cp -R form.yml metadata.yml pillar.example README.md %{buildroot}%{fdir}/metadata/%{fname}

%files
%doc README.md
%license LICENSE

%dir %attr(0755, root, salt) %{fdir}
%dir %attr(0755, root, salt) %{fdir}/states
%dir %attr(0755, root, salt) %{fdir}/metadata

%attr(0755, root, salt) %{fdir}/states/%{fname}
%attr(0755, root, salt) %{fdir}/states/%{fname}/templates
%attr(0755, root, salt) %{fdir}/metadata/%{fname}

%changelog
* Thu Mar 11 2021 nick wang <nwang@suse.com>
- Version bump 0.4.2
  * Fix github issue#15
  * Rename examples to templates
* Wed Feb 24 2021 nick wang <nwang@suse.com>
- Version bump 0.4.1
  * Support different backing device per node
  (bsc#1179529)
* Tue Jan 19 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.4.0
  * Change salt-formulas-configuration requirement in SLE12 codestream
  to a recommendation
  (bsc#1177860)
* Mon Dec 23 2019 nick wang <nwang@suse.com>
- Version 0.3.10
  * With the fix of salt-shaptools 0.2.9, doesn't need to
  estimate a long time for write I/O completion.
  (jsc#ECO-1965, jsc#SLE-4047)
* Wed Dec 18 2019 nick wang <nwang@suse.com>
- Version 0.3.9
  * Make file system after initial resync finished
  * Sleep longer in case sync source change state late
* Thu Nov 28 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.3.8
  * Add json rendering to jinja templates for old salt versions
* Wed Nov 13 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.3.7
  * Retry the packages installation to make the code more robust
* Wed Nov 13 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.3.6
  * Remove additional_repos salt state
* Mon Nov 11 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.3.5
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas (0755, root, salt)
    (boo#1142306)
* Wed Nov  6 2019 nick wang <nwang@suse.com>
- Version 0.3.4
  * Remove the duplicate default value in salt state
  * Not to install package by default
  * Remove salt indent and change the order of pillar
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Aug  7 2019 nick wang <nwang@suse.com>
- Version 0.3.3
  * Add prefix to ID to avoid conflicts
  * Install xfsprogs when need to format xfs
* Thu Jul 25 2019 nick wang <nwang@suse.com>
- Version 0.3.2, boo#1142762
  * Restructure the deploy and examples directories
  * Add examples of using NFS formula
  * Fix the issue of mkfs and mount NFS share
  * Polish the form.yml based on SUMA4.0, change some default values.
* Mon Jul 22 2019 Diego Akechi <dakechi@suse.com>
- Version 0.3.1
  * Change the requires to salt-formulas-configuration as this is
    the virtual "provides" shared by salt and SUMA to guarantee that
    the formula works integrated with both (not at the same time).
    (boo#1142306)
  * Change the directory permission to avoid file conflicts with
    SUMA.
* Mon Jul  8 2019 nick wang <nwang@suse.com>
- Version 0.3.0, jsc#SLE-6970
  * Move to SUSE org
  * Add SUSE manager support
* Mon Jun 24 2019 nick wang <nwang@suse.com>
- Version 0.2.2
  * Support make file system after initialization
  * Support mount to specific folder
  * Add habootstrap-formula pillar/tempalte
* Wed Jun  5 2019 nwang@suse.com
- Version 0.2.1
  * Polish the README
  * Add travis file for auto package to obs
  * Change node names in example
  * Modify state ID to avoid conflict of other formulas
* Wed May 15 2019 nwang@suse.com
- Version 0.2.0
  * Add description in pillar.example.
  * Support more parameters in global_common.conf
  * Fix bugs in initial sync.
  * Add promote/demote state.
  * Use grains['host'] for primary node.
- Basic manual test PASSED
* Mon May 13 2019 nwang@suse.com
- Initial version
